# `xchainpy-thorchain`

Thorchain wrapper

## Testing

Need this packages before using unit testing:
- pytest
- pytest-asyncio

Installation with pip :

```bash
$ pip install pytest
$ pip install pytest-asyncio
```

Testing :

```bash
$ python -m pytest xchainpy/xchainpy_thorchain/test/test_clients.py
```

can use other parameter like `-rP` or `-rx` for sysout